package lab15_observer.ex1;

import java.util.ArrayList;
import java.util.List;

public class PatientMonitoring {
    private final List<PatientObserver> observers = new ArrayList<>();

    private int position;
    private int bloodPressure;
    private int pulseOximetry;

    public PatientMonitoring(int position, int bloodPressure, int pulseOximetry) {
        this.position = position;
        this.bloodPressure = bloodPressure;
        this.pulseOximetry = pulseOximetry;
    }

    public void registerObserver(PatientObserver o) {
        observers.add(o);
    }

    public void removeObserver(PatientObserver o) {
        observers.remove(o);
    }

    private void notifyObservers(Problem problem) {
        for (PatientObserver o : observers) {
            o.update(problem, this);
        }
    }

    public int getPosition() {
        return position;
    }
    public int getBloodPressure() {
        return bloodPressure;
    }
    public int getPulseOximetry() {
        return pulseOximetry;
    }

    public void setPosition(int position) {
        this.position = position;
        notifyObservers(Problem.NO_PROBLEM);
    }

    public void setBloodPressure(int bloodPressure) {
        this.bloodPressure = bloodPressure;
        if (getBloodPressure() > 145) {
            notifyObservers(Problem.BLOOD_PRESSURE);
        } else {
            notifyObservers(Problem.NO_PROBLEM);
        }
    }

    public void setPulseOximetry(int pulseOximetry) {
        this.pulseOximetry = pulseOximetry;
        if (getPulseOximetry() > 85) {
            notifyObservers(Problem.OXIMETRY);
        } else {
            notifyObservers(Problem.NO_PROBLEM);
        }
    }

    @Override
    public String toString() {
        return "<Patient Position: " + position + ", BP: " + bloodPressure + ", PO: " + pulseOximetry + ">";
    }
}
